==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StackedBarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalStackedSeriesBaseDescriptionMetadata } from "./VerticalStackedSeriesBaseDescriptionMetadata";
import { StackedBarSeriesDescription } from "./StackedBarSeriesDescription";
/**
 * @hidden
 */
var StackedBarSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedBarSeriesDescriptionMetadata, _super);
    function StackedBarSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedBarSeriesDescriptionMetadata.b = function (a) {
        if (StackedBarSeriesDescriptionMetadata.a == null) {
            StackedBarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedBarSeriesDescriptionMetadata.c(StackedBarSeriesDescriptionMetadata.a);
        }
        if (a.g(StackedBarSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(StackedBarSeriesDescriptionMetadata.a);
    };
    StackedBarSeriesDescriptionMetadata.c = function (a) {
        VerticalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    StackedBarSeriesDescriptionMetadata.d = function (a) {
        StackedBarSeriesDescriptionMetadata.b(a);
        a.u("StackedBarSeries", function () { return new StackedBarSeriesDescription(); });
        a.t("StackedBarSeries", StackedBarSeriesDescriptionMetadata.a);
    };
    StackedBarSeriesDescriptionMetadata.$t = markType(StackedBarSeriesDescriptionMetadata, 'StackedBarSeriesDescriptionMetadata');
    StackedBarSeriesDescriptionMetadata.a = null;
    return StackedBarSeriesDescriptionMetadata;
}(Base));
export { StackedBarSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StackedBarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalStackedSeriesBaseDescriptionMetadata } from "./VerticalStackedSeriesBaseDescriptionMetadata";
import { StackedBarSeriesDescription } from "./StackedBarSeriesDescription";
/**
 * @hidden
 */
var StackedBarSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedBarSeriesDescriptionMetadata, _super);
    function StackedBarSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedBarSeriesDescriptionMetadata.b = function (a) {
        if (StackedBarSeriesDescriptionMetadata.a == null) {
            StackedBarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedBarSeriesDescriptionMetadata.c(StackedBarSeriesDescriptionMetadata.a);
        }
        if (a.j(StackedBarSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StackedBarSeriesDescriptionMetadata.a);
    };
    StackedBarSeriesDescriptionMetadata.c = function (a) {
        VerticalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    StackedBarSeriesDescriptionMetadata.d = function (a) {
        StackedBarSeriesDescriptionMetadata.b(a);
        a.aa("StackedBarSeries", function () { return new StackedBarSeriesDescription(); });
        a.z("StackedBarSeries", StackedBarSeriesDescriptionMetadata.a);
    };
    StackedBarSeriesDescriptionMetadata.$t = markType(StackedBarSeriesDescriptionMetadata, 'StackedBarSeriesDescriptionMetadata');
    StackedBarSeriesDescriptionMetadata.a = null;
    return StackedBarSeriesDescriptionMetadata;
}(Base));
export { StackedBarSeriesDescriptionMetadata };
